@@ -1,5 +1,5 @@
 #ifdef PYTHON_IN_R_NO_EXPLICIT_LINKING
-int ISO_C_forbids_an_empty_translation_unit = 0;
+int ISO_C_forbids_an_empty_translation_unit_Python_Explicit_Linking = 0;
 #else
 #include "PythonInR.h"
 #include "Python_Explicit_Linking.h"
